<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="da_DK" sourcelanguage="en">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="175"/>
        <source>Enter your Google account data</source>
        <translation>Indtast oplysninger til din Google-konto</translation>
    </message>
    <message>
        <location filename="retext.py" line="184"/>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <location filename="retext.py" line="185"/>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="245"/>
        <source>File toolbar</source>
        <translation>Fil-værktøjslinie</translation>
    </message>
    <message>
        <location filename="retext.py" line="247"/>
        <source>Edit toolbar</source>
        <translation>Redigering-værktøjslinie</translation>
    </message>
    <message>
        <location filename="retext.py" line="249"/>
        <source>Search toolbar</source>
        <translation>Søge-værktøjslinie</translation>
    </message>
    <message>
        <location filename="retext.py" line="251"/>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <location filename="retext.py" line="253"/>
        <source>Open</source>
        <translation>Åben</translation>
    </message>
    <message>
        <location filename="retext.py" line="255"/>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <location filename="retext.py" line="258"/>
        <source>Save as</source>
        <translation>Gem som</translation>
    </message>
    <message>
        <location filename="retext.py" line="260"/>
        <source>Print</source>
        <translation>Udskrift</translation>
    </message>
    <message>
        <location filename="retext.py" line="262"/>
        <source>Print preview</source>
        <translation>Udskriftsvisning</translation>
    </message>
    <message>
        <location filename="retext.py" line="264"/>
        <source>View HTML code</source>
        <translation>Vis HTML-kode</translation>
    </message>
    <message>
        <location filename="retext.py" line="265"/>
        <source>Change default font</source>
        <translation>Skift standardskrifttype</translation>
    </message>
    <message>
        <location filename="retext.py" line="266"/>
        <source>Find text</source>
        <translation>Find tekst</translation>
    </message>
    <message>
        <location filename="retext.py" line="270"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
    <message>
        <location filename="retext.py" line="279"/>
        <source>Live preview</source>
        <translation>Live-forhåndsvisning</translation>
    </message>
    <message>
        <location filename="retext.py" line="281"/>
        <source>Fullscreen mode</source>
        <translation>Fuldskærmsvisning</translation>
    </message>
    <message>
        <location filename="retext.py" line="288"/>
        <source>Other formats</source>
        <translation>Andre formater</translation>
    </message>
    <message>
        <location filename="retext.py" line="294"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <location filename="retext.py" line="299"/>
        <source>Redo</source>
        <translation>Gendan</translation>
    </message>
    <message>
        <location filename="retext.py" line="301"/>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <location filename="retext.py" line="303"/>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <location filename="retext.py" line="305"/>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <location filename="retext.py" line="315"/>
        <source>Enable</source>
        <translation>Aktiver</translation>
    </message>
    <message>
        <location filename="retext.py" line="316"/>
        <source>Set locale</source>
        <translation>Sæt sprogindstillinger</translation>
    </message>
    <message>
        <location filename="retext.py" line="325"/>
        <source>Plain text</source>
        <translation>Ren tekst</translation>
    </message>
    <message>
        <location filename="retext.py" line="327"/>
        <source>Use WebKit renderer</source>
        <translation>Anvend WebKit-fremviser</translation>
    </message>
    <message>
        <location filename="retext.py" line="334"/>
        <source>Generate webpages</source>
        <translation>Generer websider</translation>
    </message>
    <message>
        <location filename="retext.py" line="335"/>
        <source>Show</source>
        <translation>Vis</translation>
    </message>
    <message>
        <location filename="retext.py" line="336"/>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <location filename="retext.py" line="337"/>
        <source>Previous</source>
        <translation>Foregående</translation>
    </message>
    <message>
        <location filename="retext.py" line="339"/>
        <source>Get help online</source>
        <translation>Find hjælp online</translation>
    </message>
    <message>
        <location filename="retext.py" line="344"/>
        <source>About %s</source>
        <translation>Om %s</translation>
    </message>
    <message>
        <location filename="retext.py" line="347"/>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <location filename="retext.py" line="368"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location filename="retext.py" line="369"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="retext.py" line="370"/>
        <source>Underline</source>
        <translation>Understregning</translation>
    </message>
    <message>
        <location filename="retext.py" line="373"/>
        <source>Save to Google Docs</source>
        <translation>Gem til Google Docs</translation>
    </message>
    <message>
        <location filename="retext.py" line="380"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location filename="retext.py" line="384"/>
        <source>Symbols</source>
        <translation>Symboler</translation>
    </message>
    <message>
        <location filename="retext.py" line="408"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="retext.py" line="409"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="retext.py" line="410"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="retext.py" line="413"/>
        <source>Open recent</source>
        <translation>Åben seneste</translation>
    </message>
    <message>
        <location filename="retext.py" line="416"/>
        <source>Directory</source>
        <translation>Mappe</translation>
    </message>
    <message>
        <location filename="retext.py" line="424"/>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <location filename="retext.py" line="450"/>
        <source>Spell check</source>
        <translation>Stavekontrol</translation>
    </message>
    <message>
        <location filename="retext.py" line="458"/>
        <source>Default editing mode</source>
        <translation>Standardredigering</translation>
    </message>
    <message>
        <location filename="retext.py" line="461"/>
        <source>Formatting</source>
        <translation>Formattering</translation>
    </message>
    <message>
        <location filename="retext.py" line="499"/>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <location filename="retext.py" line="503"/>
        <source>Case sensitively</source>
        <translation>Skelnen mellem store og små bogstaver</translation>
    </message>
    <message>
        <location filename="retext.py" line="1330"/>
        <source>New document</source>
        <translation>Nyt dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Du har hverken Markdown eller Docutils installeret!</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>Only HTML formatting will be available.</source>
        <translation>Der vil kun være HTML-formattering til rådighed.</translation>
    </message>
    <message>
        <location filename="retext.py" line="726"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Indtast sprogindstilling (eksempel:en_US)</translation>
    </message>
    <message>
        <location filename="retext.py" line="813"/>
        <source>Please, save the file somewhere.</source>
        <translation>Gem venligst filen et sted.</translation>
    </message>
    <message>
        <location filename="retext.py" line="800"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Sider gemt i &lt;code&gt;html&lt;/code&gt;-mappe.</translation>
    </message>
    <message>
        <location filename="retext.py" line="802"/>
        <source>Show directory</source>
        <translation>Vis mappe</translation>
    </message>
    <message>
        <location filename="retext.py" line="807"/>
        <source>Webpages generator is not installed!</source>
        <translation>Hjemmesidegenerator ikke installeret!</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Select one or several files to open</source>
        <translation>Vælg en eller flere filer, der skal åbnes</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Supported files</source>
        <translation>Understøttede filer</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>All files (*)</source>
        <translation>Alle filer (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="984"/>
        <source>Plain text (*.txt)</source>
        <translation>Ren tekst (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="987"/>
        <source>ReStructuredText files</source>
        <translation>ReStrcturedText-filer</translation>
    </message>
    <message>
        <location filename="retext.py" line="990"/>
        <source>HTML files</source>
        <translation>HTML-filer</translation>
    </message>
    <message>
        <location filename="retext.py" line="993"/>
        <source>Markdown files</source>
        <translation>Markdown-filer</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>Save file</source>
        <translation>Gem fil</translation>
    </message>
    <message>
        <location filename="retext.py" line="1008"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Kan ikke gemme filen, fordi den er skrivebeskyttet!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>Export document to ODT</source>
        <translation>Eksporter dokument til ODT</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocument-tekstfiler (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTML-filer (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>Export document to PDF</source>
        <translation>Eksporter dokument til PDF</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDF-filer (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1109"/>
        <source>Print document</source>
        <translation>Udskriv dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="1128"/>
        <source>Export document</source>
        <translation>Eksporter dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="1151"/>
        <source>Failed to execute the command:</source>
        <translation>Kunne ikke udføre kommandoen:</translation>
    </message>
    <message>
        <location filename="retext.py" line="1158"/>
        <source>This function is not available in Plain text mode!</source>
        <translation>Denne funktion er ikke til rådighed, når man arbejder med ren tekst!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1161"/>
        <source>Select type</source>
        <translation>Vælg type</translation>
    </message>
    <message>
        <location filename="retext.py" line="1224"/>
        <source>Incorrect user name or password!</source>
        <translation>Fejl i brugernavn eller adgangskode!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1227"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Login slået fejl - efterse din internetforbindelse!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1299"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokumentet er blevet ændret.
Ønsker du at gemme dine ændringer?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1337"/>
        <source>HTML code</source>
        <translation>HTML-kode</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Enkel men stærk editor til Markdown og ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Forfatter: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Website</source>
        <translation>Hjemmeside</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Markdown syntax</source>
        <translation>Markdown-syntaks</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>ReST syntax</source>
        <translation>ReST-syntaks</translation>
    </message>
    <message>
        <location filename="retext.py" line="1411"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Kunne ikke indlæse filens indhold, efterse, at du har de rette moduler installeret!</translation>
    </message>
</context>
</TS>
